From 76c102944c8c164f2cf8908712b6c6a1d9fe5d70 Mon Sep 17 00:00:00 2001
From: Ilyes Kechidi <ilyes.spd@gmail.com>
Date: Wed, 23 Nov 2016 02:21:18 +0100
Subject: added a transfer.sh plugin created a function to easily upload files
 to transfer.sh file sharing site Usage : transfer file.txt

---
 plugins/transfer/transfer.plugin.zsh | 7 +++++++
 1 file changed, 7 insertions(+)
 create mode 100644 plugins/transfer/transfer.plugin.zsh

(limited to 'plugins/transfer/transfer.plugin.zsh')

diff --git a/plugins/transfer/transfer.plugin.zsh b/plugins/transfer/transfer.plugin.zsh
new file mode 100644
index 000000000..7d0d84bea
--- /dev/null
+++ b/plugins/transfer/transfer.plugin.zsh
@@ -0,0 +1,7 @@
+# transfer.sh Easy file sharing from the command line
+# transfer Plugin
+# Usage Example :
+# > transfer file.txt
+
+transfer() { if [ $# -eq 0 ]; then echo "No arguments specified. Usage:\necho transfer /tmp/test.md\ncat /tmp/test.md | transfer test.md"; return 1; fi 
+tmpfile=$( mktemp -t transferXXX ); if tty -s; then basefile=$(basename "$1" | sed -e 's/[^a-zA-Z0-9._-]/-/g'); curl --progress-bar --upload-file "$1" "https://transfer.sh/$basefile" >> $tmpfile; else curl --progress-bar --upload-file "-" "https://transfer.sh/$1" >> $tmpfile ; fi; cat $tmpfile; rm -f $tmpfile; }
\ No newline at end of file
-- 
cgit v1.2.3-70-g09d2


From 845fdfaae0a913143d1ff03220a1bf1596871225 Mon Sep 17 00:00:00 2001
From: Ilyes Kechidi <ilyes.spd@gmail.com>
Date: Thu, 9 Feb 2017 02:28:33 +0100
Subject: replaced transfer function with @nl5887 version

---
 plugins/transfer/transfer.plugin.zsh | 62 ++++++++++++++++++++++++++++++++++--
 1 file changed, 60 insertions(+), 2 deletions(-)

(limited to 'plugins/transfer/transfer.plugin.zsh')

diff --git a/plugins/transfer/transfer.plugin.zsh b/plugins/transfer/transfer.plugin.zsh
index 7d0d84bea..796faa9a2 100644
--- a/plugins/transfer/transfer.plugin.zsh
+++ b/plugins/transfer/transfer.plugin.zsh
@@ -2,6 +2,64 @@
 # transfer Plugin
 # Usage Example :
 # > transfer file.txt
+# > transfer directory/
 
-transfer() { if [ $# -eq 0 ]; then echo "No arguments specified. Usage:\necho transfer /tmp/test.md\ncat /tmp/test.md | transfer test.md"; return 1; fi 
-tmpfile=$( mktemp -t transferXXX ); if tty -s; then basefile=$(basename "$1" | sed -e 's/[^a-zA-Z0-9._-]/-/g'); curl --progress-bar --upload-file "$1" "https://transfer.sh/$basefile" >> $tmpfile; else curl --progress-bar --upload-file "-" "https://transfer.sh/$1" >> $tmpfile ; fi; cat $tmpfile; rm -f $tmpfile; }
\ No newline at end of file
+
+
+# Author:
+#   Remco Verhoef <remco@dutchcoders.io>
+#   https://gist.github.com/nl5887/a511f172d3fb3cd0e42d
+#
+
+curl --version 2>&1 > /dev/null
+if [ $? -ne 0 ]; then
+  echo "Could not find curl."
+  return 1
+fi
+
+transfer() { 
+    # check arguments
+    if [ $# -eq 0 ]; 
+    then 
+        echo "No arguments specified. Usage:\necho transfer /tmp/test.md\ncat /tmp/test.md | transfer test.md"
+        return 1
+    fi
+
+    # get temporarily filename, output is written to this file show progress can be showed
+    tmpfile=$( mktemp -t transferXXX )
+    
+    # upload stdin or file
+    file=$1
+
+    if tty -s; 
+    then 
+        basefile=$(basename "$file" | sed -e 's/[^a-zA-Z0-9._-]/-/g') 
+
+        if [ ! -e $file ];
+        then
+            echo "File $file doesn't exists."
+            return 1
+        fi
+        
+        if [ -d $file ];
+        then
+            # zip directory and transfer
+            zipfile=$( mktemp -t transferXXX.zip )
+            cd $(dirname $file) && zip -r -q - $(basename $file) >> $zipfile
+            curl --progress-bar --upload-file "$zipfile" "https://transfer.sh/$basefile.zip" >> $tmpfile
+            rm -f $zipfile
+        else
+            # transfer file
+            curl --progress-bar --upload-file "$file" "https://transfer.sh/$basefile" >> $tmpfile
+        fi
+    else 
+        # transfer pipe
+        curl --progress-bar --upload-file "-" "https://transfer.sh/$file" >> $tmpfile
+    fi
+   
+    # cat output link
+    cat $tmpfile
+
+    # cleanup
+    rm -f $tmpfile
+}
\ No newline at end of file
-- 
cgit v1.2.3-70-g09d2


From 05b617066ba5a37ef0c533385efd6e232a387b8f Mon Sep 17 00:00:00 2001
From: Arvindraj <arvindultimate7352@gmail.com>
Date: Fri, 2 Nov 2018 22:10:13 +0530
Subject: transfer: add deprecation notice (#7372)

Fixes #7371

Signed-off-by: Arvindraj <arvindultimate7352@gmail.com>
Co-authored-by: Stephen Ward <stephen@whilenotzero.com>
---
 plugins/transfer/README.md           |  4 ++++
 plugins/transfer/transfer.plugin.zsh | 10 +++++++++-
 2 files changed, 13 insertions(+), 1 deletion(-)

(limited to 'plugins/transfer/transfer.plugin.zsh')

diff --git a/plugins/transfer/README.md b/plugins/transfer/README.md
index 5fa064445..37c7ca2f7 100644
--- a/plugins/transfer/README.md
+++ b/plugins/transfer/README.md
@@ -1,5 +1,9 @@
 # `transfer` plugin
 
+**NOTICE: The `transfer` plugin is deprecated and will be removed soon, since the [transfer.sh](https://transfer.sh) service will be shutdown on 30th November 30th, 2018. Please move your files to an alternative file sharing service provider.**
+
+----
+
 [`transfer.sh`](https://transfer.sh) is an easy to use file sharing service from the command line
 
 ## Usage
diff --git a/plugins/transfer/transfer.plugin.zsh b/plugins/transfer/transfer.plugin.zsh
index 7a7cd85ec..8fd09ef04 100644
--- a/plugins/transfer/transfer.plugin.zsh
+++ b/plugins/transfer/transfer.plugin.zsh
@@ -12,6 +12,14 @@
 #   Modified to use tar command instead of zip
 #
 
+echo -ne '\e[1;33m'
+cat <<-EOF
+        [oh-my-zsh] WARNING: The 'transfer' plugin is deprecated and will be removed after
+        [oh-my-zsh] transfer.sh shuts down on November 30th. We suggest you stop using the
+        [oh-my-zsh] plugin and find an alternative file hosting service.
+EOF
+echo -ne '\e[0m'
+
 curl --version 2>&1 > /dev/null
 if [ $? -ne 0 ]; then
   echo "Could not find curl."
@@ -64,4 +72,4 @@ transfer() {
 
     # cleanup
     rm -f $tmpfile
-}
\ No newline at end of file
+}
-- 
cgit v1.2.3-70-g09d2


From 3d8f2bda599c8c6d160dc448e5ab28aaf2d5e90d Mon Sep 17 00:00:00 2001
From: Marc Cornellà <marc.cornella@live.com>
Date: Tue, 13 Nov 2018 10:54:33 +0100
Subject: Revert "transfer: add deprecation notice (#7372)" (#7402)

This reverts commit 05b617066ba5a37ef0c533385efd6e232a387b8f.
---
 plugins/transfer/README.md           |  4 ----
 plugins/transfer/transfer.plugin.zsh | 10 +---------
 2 files changed, 1 insertion(+), 13 deletions(-)

(limited to 'plugins/transfer/transfer.plugin.zsh')

diff --git a/plugins/transfer/README.md b/plugins/transfer/README.md
index 37c7ca2f7..5fa064445 100644
--- a/plugins/transfer/README.md
+++ b/plugins/transfer/README.md
@@ -1,9 +1,5 @@
 # `transfer` plugin
 
-**NOTICE: The `transfer` plugin is deprecated and will be removed soon, since the [transfer.sh](https://transfer.sh) service will be shutdown on 30th November 30th, 2018. Please move your files to an alternative file sharing service provider.**
-
-----
-
 [`transfer.sh`](https://transfer.sh) is an easy to use file sharing service from the command line
 
 ## Usage
diff --git a/plugins/transfer/transfer.plugin.zsh b/plugins/transfer/transfer.plugin.zsh
index 8fd09ef04..7a7cd85ec 100644
--- a/plugins/transfer/transfer.plugin.zsh
+++ b/plugins/transfer/transfer.plugin.zsh
@@ -12,14 +12,6 @@
 #   Modified to use tar command instead of zip
 #
 
-echo -ne '\e[1;33m'
-cat <<-EOF
-        [oh-my-zsh] WARNING: The 'transfer' plugin is deprecated and will be removed after
-        [oh-my-zsh] transfer.sh shuts down on November 30th. We suggest you stop using the
-        [oh-my-zsh] plugin and find an alternative file hosting service.
-EOF
-echo -ne '\e[0m'
-
 curl --version 2>&1 > /dev/null
 if [ $? -ne 0 ]; then
   echo "Could not find curl."
@@ -72,4 +64,4 @@ transfer() {
 
     # cleanup
     rm -f $tmpfile
-}
+}
\ No newline at end of file
-- 
cgit v1.2.3-70-g09d2


From 83ce8d05dfefacf1d4a7fdc957f38b3bd6cba6b4 Mon Sep 17 00:00:00 2001
From: Marc Cornellà <marc.cornella@live.com>
Date: Wed, 30 Jan 2019 16:35:16 +0100
Subject: transfer: add newline after showing the link

Fixes #7562
---
 plugins/transfer/transfer.plugin.zsh | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

(limited to 'plugins/transfer/transfer.plugin.zsh')

diff --git a/plugins/transfer/transfer.plugin.zsh b/plugins/transfer/transfer.plugin.zsh
index 7a7cd85ec..db744b0cd 100644
--- a/plugins/transfer/transfer.plugin.zsh
+++ b/plugins/transfer/transfer.plugin.zsh
@@ -61,7 +61,9 @@ transfer() {
    
     # cat output link
     cat $tmpfile
+    # add newline
+    echo
 
     # cleanup
     rm -f $tmpfile
-}
\ No newline at end of file
+}
-- 
cgit v1.2.3-70-g09d2


From c36474b7dfbe19c0628f6f21d8da40b535eeb5fb Mon Sep 17 00:00:00 2001
From: Ilyes Kechidi <ilyes.spd@gmail.com>
Date: Thu, 9 Feb 2017 19:41:09 +0100
Subject: modified the script to use tar command instead of zip

---
 plugins/transfer/transfer.plugin.zsh | 12 +++++++-----
 1 file changed, 7 insertions(+), 5 deletions(-)

(limited to 'plugins/transfer/transfer.plugin.zsh')

diff --git a/plugins/transfer/transfer.plugin.zsh b/plugins/transfer/transfer.plugin.zsh
index 796faa9a2..7a7cd85ec 100644
--- a/plugins/transfer/transfer.plugin.zsh
+++ b/plugins/transfer/transfer.plugin.zsh
@@ -9,6 +9,7 @@
 # Author:
 #   Remco Verhoef <remco@dutchcoders.io>
 #   https://gist.github.com/nl5887/a511f172d3fb3cd0e42d
+#   Modified to use tar command instead of zip
 #
 
 curl --version 2>&1 > /dev/null
@@ -43,11 +44,12 @@ transfer() {
         
         if [ -d $file ];
         then
-            # zip directory and transfer
-            zipfile=$( mktemp -t transferXXX.zip )
-            cd $(dirname $file) && zip -r -q - $(basename $file) >> $zipfile
-            curl --progress-bar --upload-file "$zipfile" "https://transfer.sh/$basefile.zip" >> $tmpfile
-            rm -f $zipfile
+            echo $file
+            # tar directory and transfer
+            tarfile=$( mktemp -t transferXXX.tar.gz )
+            cd $(dirname $file) && tar -czf $tarfile $(basename $file)
+            curl --progress-bar --upload-file "$tarfile" "https://transfer.sh/$basefile.tar.gz" >> $tmpfile
+            rm -f $tarfile
         else
             # transfer file
             curl --progress-bar --upload-file "$file" "https://transfer.sh/$basefile" >> $tmpfile
-- 
cgit v1.2.3-70-g09d2